#!/bin/bash

TIFFN=$1
echo `basename "${TIFFN}"`
ROOTFN=`basename "${TIFFN}"`
TMPDIR='/wdmcm/01/20191018_ExtremeEarth/tmp'

# Extract HH image
HHFN="${TMPDIR}/${ROOTFN/.tif/_hh.tif}"
echo $HHFN
gdal_translate -of GTIFF -ot Float32 -co "BIGTIFF=YES" -b 1 -a_nodata 0.0 "${TIFFN}" "${HHFN}"
HH8FN="${TMPDIR}/${ROOTFN/.tif/_hh_8bit.tif}"
echo $HH8FN
gdal_translate -of GTIFF -ot Byte -co "BIGTIFF=YES" -b 1 -scale 0.0 0.30 1 255 -a_nodata 0 "${TIFFN}" "${HH8FN}"

# Extract HV image
HVFN="${TMPDIR}/${ROOTFN/.tif/_hv.tif}"
echo $HVFN
gdal_translate -of GTIFF -ot Float32 -co "BIGTIFF=YES" -b 2 -a_nodata 0.0 "${TIFFN}" "${HVFN}"
HV8FN="${TMPDIR}/${ROOTFN/.tif/_hv_8bit.tif}"
echo $HV8FN
gdal_translate -of GTIFF -ot Byte -co "BIGTIFF=YES" -b 2 -scale 0.0 0.03 1 255 -a_nodata 0 "${TIFFN}" "${HV8FN}"

# Calculate the HV/HH ratio
RATIOFN="${TMPDIR}/${ROOTFN/.tif/_ratio.tif}"
echo "${RATIOFN}"
gdal_calc.py -A "${HVFN}" -B "${HHFN}" --outfile "${RATIOFN}" --creation-option="BIGTIFF=YES" --overwrite --calc="A/B" 
RATIO8FN="${TMPDIR}/${ROOTFN/.tif/_ratio_8bit.tif}"
echo $RATIO8FN
gdal_translate -of GTIFF -ot Byte -co "BIGTIFF=YES" -scale 0.0 0.30 1 255 -a_nodata 0 "${RATIOFN}" "${RATIO8FN}"

# Stack the 3 bands to create an RGB composite
echo "Merge"
OUTFN="${TMPDIR}/${ROOTFN/.tif/_rgb.tif}"
gdal_merge.py -o "${OUTFN}" -of "GTiff" -co "BIGTIFF=YES" -separate "${RATIOFN}" "${HVFN}" "${HHFN}"

OUT8FN="${TMPDIR}/${ROOTFN/.tif/_rgb_8bit.tif}"
gdal_merge.py -o "${OUT8FN}" -of "GTiff" -ot Byte -co "BIGTIFF=YES" -co "COMPRESS=JPEG" -separate -a_nodata 0 "${RATIO8FN}" "${HV8FN}" "${HH8FN}"

# Add overviews
echo "Overviews"
gdaladdo --config COMPRESS_OVERVIEW JPEG --config PHOTOMETRIC_OVERVIEW YCBCR --config INTERLEAVE_OVERVIEW PIXEL \
  -r average "${OUT8FN}" 2 4 8 16 32 64 128 256

# Clean up
rm "${HHFN}" "${HH8FN}" "${HVFN}" "${HV8FN}" "${RATIOFN}" "${RATIO8FN}" "${TMPDIR}"/*.xml

exit
  
